@@ -2,18 +2,16 @@ import logging
 
 import click
 from plugin_sdk_automation.handlers import DockerHandler
-from rich.console import Console
 from rich.logging import RichHandler
 from rich.traceback import install
 
 install()
 
-console = Console()
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.INFO)
 st = RichHandler()
-fmt = logging.Formatter("%(asctime)s - %(levelname)s - %(name)s - %(filename)s:%(lineno)d - %(message)s")
+fmt = logging.Formatter("%(filename)s:%(lineno)d - %(message)s")
 st.setFormatter(fmt)
 log.addHandler(st)
 
@@ -22,23 +20,23 @@ log.addHandler(st)
 @click.option("--debug", default=False, is_flag=True)
 @click.pass_context
 def cli(ctx, debug):
-    console.log(f"Debug is: {debug}")
+    log.info(f"Debug is: {debug}")
     if debug:
         log.setLevel(logging.DEBUG)
     if ctx.invoked_subcommand is None:
-        console.log("No subcommand provided, executing build")
+        log.info("No subcommand provided, executing build")
         ctx.invoke(build)
 
 
 @cli.command()
 @click.option("--directory", "-d")
-def build(directory: str):
-    d = DockerHandler(log=log, directory=directory)
+@click.option("--python-version", "-p", type=click.Choice(["py36", "py38"]))
+def build(directory: str, python_version: str):
+    d = DockerHandler(log=log, directory=directory, python_version=python_version)
     d.build()
 
 
 def main():
-
     cli()
 
 
